Package: interp
Type: Package
Title: Interpolation Methods
Version: 1.1-3
Date: 2022-07-12
Authors@R: c(person("Albrecht", "Gebhardt", role = c("aut", "cre", "cph"),
                     email = "albrecht.gebhardt@aau.at"),
            person("Roger", "Bivand", role = c("aut"),
                     email = "Roger.Bivand@nhh.no"),
            person("David", "Sinclair", role = c("aut","cph"),
                     email = "david@s-hull.org",
                     comment = "author of the shull library"))
Maintainer: Albrecht Gebhardt <albrecht.gebhardt@aau.at>
Description: Bivariate data interpolation on regular and irregular
  grids, either linear or using splines are the main part of this
  package.  It is intended to provide FOSS replacement functions for
  the ACM licensed akima::interp and tripack::tri.mesh functions.
  Linear interpolation is implemented in 
  interp::interp(..., method="linear"), this corresponds to the call 
  akima::interp(..., linear=TRUE) which is the default setting and 
  covers most of akima::interp use cases in depending packages.  
  A re-implementation of Akimas irregular grid spline
  interpolation (akima::interp(..., linear=FALSE)) is now also
  available via interp::interp(..., method="akima").
  Estimators for partial derivatives are now also available in 
  interp::locpoly(), these are a prerequisite for the spline interpolation.  
  The basic part is a GPLed triangulation algorithm (sweep hull 
  algorithm by David Sinclair) providing the starting point for the
  irregular grid interpolator. As side effect this algorithm is also
  used to provide replacements for almost all functions of the tripack
  package which also suffers from the same ACM license restrictions.  
  All functions are designed to be backward compatible with their 
  akima / tripack counterparts.
License: GPL (>= 2)
Imports: Rcpp (>= 0.12.9), deldir
Suggests: sp, Deriv, Ryacas, ggplot2, gridExtra, lattice, stringi,
        stringr
Enhances: RcppEigen
LinkingTo: Rcpp, RcppEigen
Depends: R (>= 3.5.0)
NeedsCompilation: yes
Packaged: 2022-07-13 18:57:53 UTC; alge
Author: Albrecht Gebhardt [aut, cre, cph],
  Roger Bivand [aut],
  David Sinclair [aut, cph] (author of the shull library)
Repository: CRAN
Date/Publication: 2022-07-13 20:00:02 UTC
