This package contains a FOSS (re)implementation of the interp* functions from
package akima, as well as FOSS version of most functions of package tripack.

These functions are backward compatible in their arguments.

